changeset 13713:a5b409d8d6a8

2812 FMA generic topology support for AMD family 0x10 model 10 Reviewed by: Hans Rosenfeld <rosenfeld@grumpf.hope-2000.org> Reviewed by: Garrett D'Amore <garrett@damore.org> Approved by: Richard Lowe <richlowe@richlowe.net>
author Jens Elkner <jel+illumos@cs.uni-magdeburg.de>
date Sun, 03 Jun 2012 13:11:46 -0500
parents 236e80401f3d
children e2f6dabb84ef
files usr/src/lib/fm/topo/modules/i86pc/chip/chip_amd.c
diffstat 1 files changed, 3 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/usr/src/lib/fm/topo/modules/i86pc/chip/chip_amd.c	Tue Jun 05 12:45:22 2012 -0700
+++ b/usr/src/lib/fm/topo/modules/i86pc/chip/chip_amd.c	Sun Jun 03 13:11:46 2012 -0500
@@ -144,11 +144,11 @@
 	/*
 	 * Elsewhere we have already returned for families less than 0xf.
 	 * This "generic" topology is adequate for all of family 0xf and
-	 * for revisions A to D of family 0x10 (for the list of models
+	 * for revisions A to E of family 0x10 (for the list of models
 	 * in each revision, refer to usr/src/uts/i86pc/os/cpuid_subr.c).
 	 * We cover all family 0x10 models, till model 9.
 	 */
-	if (family > 0x10 || (family == 0x10 && model > 9))
+	if (family > 0x10 || (family == 0x10 && model > 10))
 		return (1);
 
 	if (topo_node_range_create(mod, mcnode, CHAN_NODE_NAME, 0,
@@ -144,11 +144,11 @@
 	 * in each revision, refer to usr/src/uts/i86pc/os/cpuid_subr.c).
-	 * We cover all family 0x10 models, till model 9.
+	 * We cover all family 0x10 models, till model 10.
 	 */